@@ -6,6 +6,18 @@
 
 from datetime import datetime, timedelta, timezone
 from dateutil import parser
+from re import sub
+
+
+class _QueryUtil(object):
+
+    @staticmethod
+    def encode_odata_query_value(value):
+        """Encode value strings according to OData query rules.
+        http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part2-url-conventions.html#sec_URLParsing
+        http://docs.oasis-open.org/odata/odata/v4.01/cs01/abnf/odata-abnf-construction-rules.txt """
+        # single quotes escaped through single quote
+        return sub('\'', '\'\'', value)
 
 
 class _DateUtil(object):
